<?php
$image = \Blue2\Scruffy\Site::acfImage(get_sub_field('image')['id'], 'info-block-section');
$title = get_sub_field('title');
$description = get_sub_field('description');
$id = get_sub_field('section_id');
?>
<section class="custom-flexible-section info-block-section" id="<?= $id; ?>">
    <div class="contain">
        <div class="block-wrapper">
            <div class="row no-gutters row-eq-height">
                <div class="col-lg-6 col-xl-7">
                    <div class="image-section <?= $image['class']; ?>">
                        <?= $image['output']; ?>
                    </div>
                </div>
                <div class="col-lg-6 col-xl-5">
                    <div class="content-section">
                        <?php if($title) { ?><h2 class="fw-700"><?= $title; ?></h2><?php } ?>
                        <?php if($description) { ?><div class="description"><?= $description; ?></div><?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
